<?php
/* --------------------------------------------------------------
   BasicElement.inc.php 2019-03-14
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

namespace Gambio\StyleEdit\Core\Components\Variant\Commands;

use Exception;
use Gambio\StyleEdit\Core\BuildStrategies\Interfaces\AlwaysNewStrategyInterface;
use Gambio\StyleEdit\Core\Command\CommandInterface;
use Gambio\StyleEdit\Core\Components\Variant\Entities\VariantOption;
use Gambio\StyleEdit\Core\Components\Variant\Services\VariantService;
use Gambio\StyleEdit\Core\Options\Commands\AbstractSaveCommand;
use Gambio\StyleEdit\Core\Repositories\ConfigurationRepository;

/**
 * Class VariantSaveCommand
 * @package Gambio\StyleEdit\Core\Components\Variant\Commands
 */
class VariantSaveCommand extends AbstractSaveCommand implements CommandInterface, AlwaysNewStrategyInterface
{
    /**
     * @var VariantService
     */
    protected $variantService;
    /**
     * @var ConfigurationRepository
     */
    private $configurationRepository;


    /**
     * VariantSaveCommand constructor.
     *
     * @param VariantService $variantService
     * @param ConfigurationRepository $configurationRepository
     */
    public function __construct(VariantService $variantService, ConfigurationRepository $configurationRepository)
    {
        $this->variantService = $variantService;
        $this->configurationRepository = $configurationRepository;
    }


    /**
     * Execute the command
     *
     * @throws Exception
     */
    public function execute(): void
    {
        $this->saveOption();
        $this->restoreVariantSettings();
    }


    /**
     * @throws Exception
     */
    protected function restoreVariantSettings()
    {
        if (is_a($this->option, VariantOption::class)) {
            if ($this->variantService->exists($this->option()->id(), $this->option()->value()->id())) {
                $settings = $this->variantService->getSettingsFromVariant(
                    $this->option()->id(),
                    $this->option()->value()->id()
                );
                foreach ($settings->getIterator() as $setting) {
                    $this->configurationRepository->saveJsonConfigurationFrom($setting);
                }
            }
        }
    }


    /**
     * @return VariantOption
     */
    protected function option(): VariantOption
    {
        return $this->option;
    }


    /**
     * Execute the command
     */
    public function rollback(): void
    {
        // TODO: Implement rollback() method.
    }
}