<?php

namespace Gambio\StyleEdit\Core\Repositories\Entities;

use Gambio\StyleEdit\Core\SingletonPrototype;
use JsonSerializable;

/**
 * Class Configuration
 * @package Gambio\StyleEdit\Core\Repositories\Entities
 */
class Configuration implements JsonSerializable
{
    protected $value;
    protected $id;
    protected $type;
    protected $group;
    
    /**
     * @return mixed
     */
    public function group()
    {
        return $this->group;
    }
    
    
    /**
     * @return mixed
     */
    public function value()
    {
        return $this->value;
    }
    
    
    /**
     * @return mixed
     */
    public function id()
    {
        return $this->id;
    }
    
    
    /**
     * @return mixed
     */
    public function type()
    {
        return $this->type;
    }
    
    /**
     * @param $jsonObject
     *
     * @return \Gambio\StyleEdit\Core\Repositories\Entities\Configuration
     * @throws \Exception
     */
    public static function createFromJson($jsonObject)
    {
        $result        = SingletonPrototype::instance()->get(static::class);
        $result->value = $jsonObject->value;
        
        if (isset($jsonObject->type)) {
            $result->type = $jsonObject->type;
        }
        
        if (!isset($jsonObject->group) || $jsonObject->group === null) {
            
            throw new \Exception('Group unspecified in Configuration with the id :"' . $jsonObject->name . '"');
        }
        
        $result->id    = $jsonObject->name;
        $result->group = $jsonObject->group;
        
        
        return $result;
    }
    
    
    /**
     * Specify data which should be serialized to JSON
     * @link  https://php.net/manual/en/jsonserializable.jsonserialize.php
     * @return mixed data which can be serialized by <b>json_encode</b>,
     * which is a value of any type other than a resource.
     * @since 5.4.0
     */
    public function jsonSerialize()
    {
        return (object)[
            'name'  => $this->id(),
            'value' => $this->value(),
            'type'  => $this->type(),
            'group' => $this->group()
        
        ];
    }
}